xml: Bank.xml, xsl: makeSkeleton.xsl

package	BankingSystem;





/**
 * Title:        Node 2 Node IPC
 * Description:  Simple IPC via interfaces application using IDL based interfaces
 * Copyright:    Copyright (c) 2000
 * Company:      TROy Software Products
 * @author Selvyn Wright
 * @version 1.0
 */

import	java.io.*;
import	node2node_ipc.TSocketMessageBase;
import	node2node_ipc.messages.*;
import  node2node_ipc.*;


public class TBankSkeleton extends TEventListenerAdaptor
{
   private  Bank   itsImpl = null;

   private  void  init( Bank impl )
   {
      itsImpl = impl;

      try
      {
         TSocketHandler.getMonitor().addByteSocketListener( this );
      }
      catch( java.lang.ExceptionInInitializerError e )
      {
         e.printStackTrace();
      }
   }

   public TBankSkeleton( String typeName, Bank impl, String objID )
   {
      itsTypeName = typeName;
      itsObjectID = objID.getBytes();

      init( impl );
   }

   public TBankSkeleton( Bank impl )
   {
      init( impl );
   }

	public void dataAvailable( TSocketMessageBase msg, TObjectAdaptor reader ) throws node2node_ipc.TSystemException
	{
 		String opName = msg.operationName();

		if( TSocketHandler.diagnostics() )
			System.out.println( "Bank.Operation found: " + opName );

		if( opName.equals( new String("getAccount") ) )
		{
			getAccount( msg, reader );
		}

		else
	
		if( opName.equals( new String("closeAccount") ) )
		{
			closeAccount( msg, reader );
		}

		else
	
		if( opName.equals( new String("createAccount") ) )
		{
			createAccount( msg, reader );
		}

		else
	
		if( opName.equals( new String("getAccounts") ) )
		{
			getAccounts( msg, reader );
		}

		else
	
		if( opName.equals( new String("addAccount") ) )
		{
			addAccount( msg, reader );
		}

		else
	
		if( opName.equals( new String("addAccountWithCustomer") ) )
		{
			addAccountWithCustomer( msg, reader );
		}

	}

	private	void	getAccount( TSocketMessageBase msg, TObjectAdaptor reader ) throws node2node_ipc.TSystemException
	{
		// unpack parameters...
		
		String	p1 = msg.readString();
		
	
		// Gonna return a [Account] interface...
		Account result = itsImpl.getAccount( p1
												 );
		TSendMessage newMsg = new TSendMessage( msg.getSocket(), "n2n:", result.listener().objectId(), "@@" );
      	newMsg.send();
		
		
	}

	private	void	closeAccount( TSocketMessageBase msg, TObjectAdaptor reader ) throws node2node_ipc.TSystemException
	{
		// unpack parameters...
		
		String	p1 = msg.readString();
		
	
		itsImpl.closeAccount( p1
												 );
		TSendMessage newMsg = new TSendMessage( msg.getSocket(), "n2n:", objectId(), "@@" );
      	newMsg.send();
		
		
	}

	private	void	createAccount( TSocketMessageBase msg, TObjectAdaptor reader ) throws node2node_ipc.TSystemException
	{
		// unpack parameters...
		
		String	p1 = msg.readString();
		
	int result = itsImpl.createAccount( p1
												 );
		TSendMessage newMsg = new TSendMessage( msg.getSocket(), "n2n:", objectId(), "@@" );
		
		
		newMsg.writeInt( result );
	
      	newMsg.send();
		
		
	}

	private	void	getAccounts( TSocketMessageBase msg, TObjectAdaptor reader ) throws node2node_ipc.TSystemException
	{
		// unpack parameters...
		
		int	p1 = msg.readInt();
		int	p2 = msg.readInt();
		
	Account[] result = itsImpl.getAccounts( p1,p2
												 );
		TSendMessage newMsg = new TSendMessage( msg.getSocket(), "n2n:", objectId(), "@@" );
		
		
		
		newMsg.writeObject( result );
	
      	newMsg.send();
		
		
	}

	private	void	addAccount( TSocketMessageBase msg, TObjectAdaptor reader ) throws node2node_ipc.TSystemException
	{
		// unpack parameters...
		
		
		// unpacking stub data...
		TAccountStub p1;
		// This param will be the object ID of the object being sent
		String id1 = msg.readString();

		// set alternate dispatching route
		TSocketMessageBase objMsg1 = reader.alternateClientPortal();

		objMsg1.overrideObjectID( id1.getBytes() );

		p1 = new TAccountStub( objMsg1 );
	
		
	
		itsImpl.addAccount( p1
												 );
		TSendMessage newMsg = new TSendMessage( msg.getSocket(), "n2n:", objectId(), "@@" );
      	newMsg.send();
		
		
	}

	private	void	addAccountWithCustomer( TSocketMessageBase msg, TObjectAdaptor reader ) throws node2node_ipc.TSystemException
	{
		// unpack parameters...
		
		
		// unpacking stub data...
		TAccountStub p1;
		// This param will be the object ID of the object being sent
		String id1 = msg.readString();

		// set alternate dispatching route
		TSocketMessageBase objMsg1 = reader.alternateClientPortal();

		objMsg1.overrideObjectID( id1.getBytes() );

		p1 = new TAccountStub( objMsg1 );
	
		Customer	p2 = (Customer)msg.readObject();
		
	
		itsImpl.addAccountWithCustomer( p1,p2
												 );
		TSendMessage newMsg = new TSendMessage( msg.getSocket(), "n2n:", objectId(), "@@" );
      	newMsg.send();
		
		
	}


}