<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:output method="text" indent="yes"/>

<xsl:template match="*|/"><xsl:apply-templates/></xsl:template>

<xsl:template match="text()|@*"><xsl:value-of select="."/></xsl:template>

<xsl:template match="module">
package	<xsl:value-of select="@name"/>;
<!-- Create a local variable containing all the forward nodes -->
<xsl:variable name="forwards">
	<xsl:apply-templates select="forward"/>
</xsl:variable>
<!-- Call the interfaces rule with the forward nodes -->
<xsl:apply-templates select="interface">
	<xsl:with-param name="interface_forwards" select="$forwards"/>
</xsl:apply-templates>
</xsl:template>

<xsl:template match="forward"><xsl:value-of select="@name"/>
</xsl:template>

<xsl:template match="interface">
<xsl:param name="interface_forwards"/>

<!-- command that follows simply dumps the contents of the parameter to see what it contains -->
<!-- <xsl:value-of select="$interface_forwards"/> -->
/**
 * Title:        Node 2 Node IPC
 * Description:  Simple IPC via interfaces application using IDL based interfaces
 * Copyright:    Copyright (c) 2000
 * Company:      TROy Software Products
 * @author Selvyn Wright
 * @version 1.0
 */

import	java.io.*;
import	node2node_ipc.TSocketMessageBase;
import	node2node_ipc.messages.*;
import  node2node_ipc.*;


public class T<xsl:value-of select="@name"/>Skeleton extends TEventListenerAdaptor
{
   private  <xsl:value-of select="@name"/>   itsImpl = null;

   private  void  init( <xsl:value-of select="@name"/> impl )
   {
      itsImpl = impl;

      try
      {
         TSocketHandler.getMonitor().addByteSocketListener( this );
      }
      catch( java.lang.ExceptionInInitializerError e )
      {
         e.printStackTrace();
      }
   }

   public T<xsl:value-of select="@name"/>Skeleton( String typeName, <xsl:value-of select="@name"/> impl, String objID )
   {
      itsTypeName = typeName;
      itsObjectID = objID.getBytes();

      init( impl );
   }

   public T<xsl:value-of select="@name"/>Skeleton( <xsl:value-of select="@name"/> impl )
   {
      init( impl );
   }

	public void dataAvailable( TSocketMessageBase msg, TObjectAdaptor reader ) throws node2node_ipc.TSystemException
	{
 		String opName = msg.operationName();

		if( TSocketHandler.diagnostics() )
			System.out.println( "<xsl:value-of select="@name"/>.Operation found: " + opName );
<xsl:for-each select="operation">
	<xsl:if test="position() != 1">
		else
	</xsl:if>
		if( opName.equals( new String("<xsl:value-of select="@name"/>") ) )
		{
			<xsl:value-of select="@name"/>( msg, reader );
		}
</xsl:for-each>
	}
<xsl:apply-templates select="operation">
	<xsl:with-param name="local_forwards" select="$interface_forwards"/>
</xsl:apply-templates>
}</xsl:template>

<xsl:template match="operation">
<xsl:param name="local_forwards"/>
	private	void<xsl:text>	</xsl:text><xsl:value-of select="@name"/>( TSocketMessageBase msg, TObjectAdaptor reader ) throws node2node_ipc.TSystemException
	{
		// unpack parameters...
		<xsl:apply-templates mode="get values">
			<xsl:with-param name="local_forwards" select="$local_forwards"/>
		</xsl:apply-templates>
		<xsl:choose>
		<xsl:when test="@mode='sync'">
		<xsl:choose>
		<xsl:when test="contains($local_forwards, return/@type)">
		// Gonna return a [<xsl:value-of select="return/@type"/>] interface...
		<xsl:value-of select="return/@type"/> result = itsImpl.<xsl:value-of select="@name"/>( <xsl:for-each select="param">p<xsl:number/>
												<xsl:if test="position() != last()">,</xsl:if>
												</xsl:for-each> );
		TSendMessage newMsg = new TSendMessage( msg.getSocket(), "n2n:", result.listener().objectId(), "@@" );
      	newMsg.send();
		</xsl:when>
		<xsl:when test="return/@type != 'void'">
		<xsl:value-of select="return/@type"/> result = itsImpl.<xsl:value-of select="@name"/>( <xsl:for-each select="param">p<xsl:number/>
												<xsl:if test="position() != last()">,</xsl:if>
												</xsl:for-each> );
		TSendMessage newMsg = new TSendMessage( msg.getSocket(), "n2n:", objectId(), "@@" );
		<xsl:apply-templates mode="set return value"/>
      	newMsg.send();
		</xsl:when>
		<xsl:otherwise>
		itsImpl.<xsl:value-of select="@name"/>( <xsl:for-each select="param">p<xsl:number/>
												<xsl:if test="position() != last()">,</xsl:if>
												</xsl:for-each> );
		TSendMessage newMsg = new TSendMessage( msg.getSocket(), "n2n:", objectId(), "@@" );
      	newMsg.send();
		</xsl:otherwise>
		</xsl:choose>
		</xsl:when>
		<xsl:otherwise>
		itsImpl.<xsl:value-of select="@name"/>( <xsl:for-each select="param">p<xsl:number/>
												<xsl:if test="position() != last()">,</xsl:if>
												</xsl:for-each> );
		</xsl:otherwise>
		</xsl:choose>
	}
</xsl:template>

<xsl:template match="param" mode="get values"><xsl:param name="local_forwards"/>
<xsl:choose>
	<xsl:when test="contains($local_forwards, @type)">
		// unpacking stub data...
		T<xsl:value-of select="@type"/>Stub p<xsl:number/>;
		// This param will be the object ID of the object being sent
		String id<xsl:number/> = msg.readString();

		// set alternate dispatching route
		TSocketMessageBase objMsg<xsl:number/> = reader.alternateClientPortal();

		objMsg<xsl:number/>.overrideObjectID( id<xsl:number/>.getBytes() );

		p<xsl:number/> = new T<xsl:value-of select="@type"/>Stub( objMsg<xsl:number/> );
	</xsl:when>
	<xsl:otherwise>
	<xsl:call-template name="find param"/>	p<xsl:number/> = <xsl:choose>
	<xsl:when test="@type='float'">msg.readFloat();</xsl:when>
	<xsl:when test="@type='char'">msg.readChar();</xsl:when>
	<xsl:when test="@type='int'">msg.readInt();</xsl:when>
	<xsl:when test="@type='date'">msg.readDate();</xsl:when>
	<xsl:when test="@type='byte'">msg.readByte();</xsl:when>
	<xsl:when test="@type='double'">msg.readDouble();</xsl:when>
	<xsl:when test="@type='string'">msg.readString();</xsl:when>
	<xsl:when test="@type='long'">msg.readLong();</xsl:when>
	<xsl:when test="@type='boolean'">msg.readBool();</xsl:when>
	<xsl:otherwise>(<xsl:value-of select="@type"/>)msg.readObject();</xsl:otherwise>
	</xsl:choose>
	</xsl:otherwise>
</xsl:choose></xsl:template>

<xsl:template match="return" mode="set return value"><xsl:choose>
	<xsl:when test="@type='float'">newMsg.writeFloat( result );</xsl:when>
	<xsl:when test="@type='char'">newMsg.writeChar( result );</xsl:when>
	<xsl:when test="@type='int'">newMsg.writeInt( result );</xsl:when>
	<xsl:when test="@type='date'">newMsg.writeDate( result );</xsl:when>
	<xsl:when test="@type='byte'">newMsg.writeByte( result );</xsl:when>
	<xsl:when test="@type='double'">newMsg.writeDouble( result );</xsl:when>
	<xsl:when test="@type='string'">newMsg.writeString( result );</xsl:when>
	<xsl:when test="@type='long'">newMsg.writeLong( result );</xsl:when>
	<xsl:when test="@type='boolean'">newMsg.writeBool( result );</xsl:when>
	<xsl:otherwise>newMsg.writeObject( result );</xsl:otherwise>
</xsl:choose></xsl:template>

<xsl:template name="find param">
<xsl:choose>
	<xsl:when test="@type='float'">float</xsl:when>
	<xsl:when test="@type='char'">char</xsl:when>
	<xsl:when test="@type='int'">int</xsl:when>
	<xsl:when test="@type='date'">Date</xsl:when>
	<xsl:when test="@type='byte'">byte</xsl:when>
	<xsl:when test="@type='double'">double</xsl:when>
	<xsl:when test="@type='string'">String</xsl:when>
	<xsl:when test="@type='long'">long</xsl:when>
	<xsl:when test="@type='boolean'">bool</xsl:when>
	<xsl:otherwise><xsl:value-of select="@type"/></xsl:otherwise>
</xsl:choose>
</xsl:template>

</xsl:stylesheet>
